<template>
  <win-md title="新增规格型号" @close="close" width="500px" :loading="loading">
    <el-form ref="ruleForm" :model="formData" :rules="rules" class="demo-ruleForm" label-width="100px">
      <el-form-item label="型号名称" prop="modelName">
        <el-input v-model="formData.modelName" placeholder="请输入型号名称" clearable maxlength="20" show-word-limit
                  style="width: 100%"/>
      </el-form-item>
      <el-form-item label="单位" prop="unit">
        <el-input v-model="formData.unit" placeholder="请输入单位" clearable maxlength="20" show-word-limit
                  style="width: 100%"/>
      </el-form-item>
      <el-form-item label="状态" prop="states">
        <el-radio-group v-model="formData.states">
          <el-radio :label="1" border>启用</el-radio>
          <el-radio :label="0" border>禁用</el-radio>
        </el-radio-group>
      </el-form-item>
    </el-form>
    <div slot="footer" align="center" class="dialog-footer">
      <my-button name="取消" site="form" @click="close"/>
      <my-button name="保存" site="form" @click="save"/>
    </div>
  </win-md>
</template>

<script>
import winMd from '@/components/win/win-md'
import myButton from '@/components/myButton/myButton'
import {mapGetters} from 'vuex'
import {addSpecs} from "@/api/foudation/material";


export default {
  name: 'specsAdd',
  components: {winMd, myButton},
  props: {
    setting: {
      type: Object,
      default: () => {
      }
    }
  },
  data() {
    return {
      loading: false,
      formData: {
        goodsTemplatesId: '',
        modelName: '',
        unit: '',
        states: 1,
      },
      rules: {
        modelName: [
          {required: true, message: '请输入型号名称', trigger: 'blur'}
        ],
        unit: [
          {required: true, message: '请输入单位', trigger: 'blur'}
        ]
      }
    }
  },
  computed: {
    ...mapGetters(['userInfo'])
  },
  created() {
  },
  methods: {
    close() {
      this.$emit('close')
    },
    save() {
      this.$refs.ruleForm.validate((valid) => {
        if (valid) {
          const params = Object.assign({}, this.formData)
          params.goodsTemplatesId = this.setting.goodsTemplatesId
          if (this.loading) return
          this.loading = true
          addSpecs(params).then(res => {
            this.loading = false
            this.$message.success('保存成功！')
            this.close()
            this.$emit('search')
          }).catch(() => {
            this.loading = false
          });
        } else {
          this.$message.error('校验未通过，请检查。')
        }
      })
    }
  }
}
</script>
